@@ -26,7 +26,6 @@ kAction = ['create', 'recreate', 'update', 'list', 'show', 'remove']
 kConfigAction = ['create', 'recreate', 'update']
 kConfigList = ['hpo_config', 'grid_config', 'search_space', 'model_config', 'project_config']
 
-
 class ConfigurationBase():
 
     def __init__(self):
@@ -249,6 +248,16 @@ class HPOConfiguration(ConfigurationBase):
 
         return config
 
+    
+class ValidateSites(argparse.Action):
+    def __call__(self, parser, args, values, option_string=None):
+        for site in values:
+            if site not in kGPUGridSiteList:
+                raise ValueError('Invalid site {}. '
+                    'Please choose one of {}'.format(site, kGPUGridSiteList))
+        setattr(args, self.dest, ','.join(values))
+                
+                
 class GridConfiguration(ConfigurationBase):
 
     def initialize(self):
@@ -265,7 +274,7 @@ class GridConfiguration(ConfigurationBase):
             parser.add_argument('-s', '--site', 
                                 help='Name of the grid site to where the jobs are submitted',
                                 required=False, default=kDefaultGridSite,
-                                choices=kGPUGridSiteList)
+                                action=ValidateSites)
             parser.add_argument('-c', '--container', metavar='',
                                 help='Name of the docker or singularity container in which the jobs are run', 
                                 required=False, default=kDefaultContainer)
