@@ -35,7 +35,7 @@ kDefaultLogDir = './log'
 kDefaultTrials = 100
 kDefaultStopping = '{"training_iteration": 1}'
 kDefaultSchedulerParam = '{}'
-kDefaultAlgorithmParam = '{"max_concurrent": 4}'
+kDefaultAlgorithmParam = '{}'
 kDefaultModelParam = '{}'
 
 kDefaultOutDS = 'user.${{RUCIO_ACCOUNT}}.hpogrid.{HPO_PROJECT_NAME}.out.$(date +%Y%m%d%H%M%S)'
