@@ -22,35 +22,20 @@ class ColorCode():
     UNDERLINE = '\033[4m'
     BLINK = '\033[5m'
 
-
-def yaml_nested_dict(data, depth=1, layer=0):
-    data = copy.deepcopy(data)
-    if layer < depth:
-        layer += 1
-        for d in data:
-            if (layer == depth):
-                if isinstance(data[d], dict):
-                    data[d] = yaml.dump(data[d], allow_unicode=True,
-                                       default_flow_style=False, sort_keys=False)
-            else:
-                data[d] = dict_to_yaml(data[d], depth, layer)
-    return data
-
 def create_table(data, columns=None, indexed=True, transpose=False,
-    tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign):
-
-    df = pd.DataFrame(data, columns=columns)
+    tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign,
+    wrap_nested_dict=False):
+    _data = copy.deepcopy(data)
+    if isinstance(_data, dict):
+        for key in _data:
+            if isinstance(_data[key], dict):
+                _data[key] = yaml.dump(_data[key], allow_unicode=True,
+                                       default_flow_style=False, sort_keys=False)
+    _data = _data.items() if isinstance(data, dict) else _data
+    df = pd.DataFrame(_data, columns=columns)
     if transpose:
         df = df.transpose()
     table = tabulate(df, showindex=indexed, headers=df.columns, 
         tablefmt=tableformat,
         stralign=stralign)
-    return table
-
-def create_formatted_dict(data, columns=None, indexed=True, transpose=False,
-    tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign, yaml_depth=None):
-    if yaml_depth:
-        data = yaml_nested_dict(data, yaml_depth)
-    return create_table(data.items(), columns, indexed, transpose, tableformat, stralign)
-
-    
+    return table
\ No newline at end of file
